@@ -1,12 +1,7 @@
 package Dist::Data;
-BEGIN {
-  $Dist::Data::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $Dist::Data::VERSION = '0.005';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: API to access the data of a Perl distribution file or directory
-
+$Dist::Data::VERSION = '0.006';
 use Moo;
 use Archive::Any;
 use CPAN::Meta;
@@ -304,7 +299,7 @@ Dist::Data - API to access the data of a Perl distribution file or directory
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
